==> openGion_core_5.5.5.0.zip: ge/db/firebird/sql/01_TABLE/GE34S.sql <==
/**************************************************************************/
/* GE34 ( 宛先テーブル )                                                  */
/*                                                                        */
/* Created : 2012/07/28 16:35:16                                          */
/**************************************************************************/
CREATE TABLE GE34 (
   YKNO     NUMERIC(9)      DEFAULT 0   NOT NULL      /* 10  要求ＮＯ       */
 , GROUP_ID VARCHAR(20)                               /* 20  グループID     */
 , DST_ID   VARCHAR(10)                 NOT NULL      /* 30  社員番号       */
 , DST_NAME VARCHAR(100)                              /* 40  名前           */
 , DST_ADDR VARCHAR(100)                              /* 50  メールアドレス */
 , DST_KBN  VARCHAR(1)                  NOT NULL      /* 60  送信区分       */
 , UNIQ     BIGINT                      NOT NULL      /* 800 ユニークキー   */
 , FGJ      VARCHAR(1)      DEFAULT '1' NOT NULL      /* 810 状態フラグ     */
 , DYSET    VARCHAR(14)                               /* 820 登録日時       */
 , PGSET    VARCHAR(10)                               /* 830 作成PG         */
 , PGPSET   VARCHAR(10)                               /* 840 作成親PG       */
 , USRSET   VARCHAR(10)                               /* 850 作成社員       */
 , DYUPD    VARCHAR(14)                               /* 860 更新日時       */
 , PGUPD    VARCHAR(10)                               /* 870 更新PG         */
 , PGPUPD   VARCHAR(10)                               /* 880 更新親PG       */
 , USRUPD   VARCHAR(10)                               /* 890 更新者         */
);

CREATE SEQUENCE GE34S00 ;


CREATE TRIGGER GE34T00 FOR GE34
  BEFORE INSERT 
  AS BEGIN 
    NEW.UNIQ = GEN_ID( GE34S00,1 );
  END;

==> openGion_core_5.6.5.1.zip: ge/db/firebird/sql/01_TABLE/GE34S.sql <==
/**************************************************************************/
/* GE34 ( 宛先テーブル )                                                  */
/*                                                                        */
/* Created : 2013/03/27 19:06:21                                          */
/**************************************************************************/
CREATE TABLE GE34 (
   YKNO     INTEGER         DEFAULT 0   NOT NULL      /* 10  要求ＮＯ       */
 , GROUP_ID VARCHAR(20)                               /* 20  グループID     */
 , DST_ID   VARCHAR(10)                 NOT NULL      /* 30  社員番号       */
 , DST_NAME VARCHAR(100)                              /* 40  名前           */
 , DST_ADDR VARCHAR(100)                              /* 50  メールアドレス */
 , DST_KBN  VARCHAR(1)                  NOT NULL      /* 60  送信区分       */
 , UNIQ     BIGINT                      NOT NULL      /* 800 ユニークキー   */
 , FGJ      VARCHAR(1)      DEFAULT '1' NOT NULL      /* 810 状態フラグ     */
 , DYSET    VARCHAR(14)                               /* 820 登録日時       */
 , PGSET    VARCHAR(10)                               /* 830 作成PG         */
 , PGPSET   VARCHAR(10)                               /* 840 作成親PG       */
 , USRSET   VARCHAR(10)                               /* 850 作成社員       */
 , DYUPD    VARCHAR(14)                               /* 860 更新日時       */
 , PGUPD    VARCHAR(10)                               /* 870 更新PG         */
 , PGPUPD   VARCHAR(10)                               /* 880 更新親PG       */
 , USRUPD   VARCHAR(10)                               /* 890 更新者         */
);

CREATE SEQUENCE GE34S00 ;


CREATE TRIGGER GE34T00 FOR GE34
  BEFORE INSERT 
  AS BEGIN 
    NEW.UNIQ = GEN_ID( GE34S00,1 );
  END;
